##  Understanding Best-Practice Metrics
The reasoning behind various best practice metrics is explained in the following sections.
### Business Capabilities
The following table lists best practice metrics and explanations for business capability fact sheets.
Best Practice Metric | Explanation
---|---
Level 1 business capabilities: Add a minimum of 7, but no more than 20 to the workspace. Level 2 business capabilities: Add a minimum of 5, but no more than 10 for each level 1 business capability. |  In general, capturing 7-20 business capabilities at level 1 provides a robust foundation and comprehensive overview for organizations. Adhering to the MECE principle (Mutually Exclusive, Completely Exhaustive) becomes challenging with a high number of business capabilities. Avoiding excessive granularity is important to balance effort and productivity. This strategic approach supports initial use cases and provides further insights once a comprehensive business capability model is established. This methodology aligns with capability-based planning, Pace Layering, and strategy/goal alignment.
Add no more than 3 levels of business capability hierarchy to the workspace. | Excessive depth in your categorization may lead to over-compartmentalization, potentially making it challenging for most users to understand business capabilities.
Ensure that at least 80% of business capabilities have a description. | Clear, concise, and universally understood definitions of business capabilities are crucial for your organization and stakeholders. This clarity is key to facilitating effective analysis and generating insightful outcomes within SAP LeanIX.


###  Organizations
The following table lists best practice metrics and explanations for organization fact sheets.
Best Practice Metric | Explanation
---|---
Level 1 organization: Add a minimum of 15, but no more than 20 to the workspace. Level 2 organization: Add a minimum of 5, but no more than 10 for each level 1 organization. | Starting with 15-20 organizations at level 1 provides a robust foundation and comprehensive overview while keeping the maintenance effort manageable. You can add more organizations at any time if needed.
Add no more than 2 levels of organization hierarchy to the workspace. | Avoiding excessive granularity is important to balance effort and productivity.
Ensure that at least 80% of organizations have a description. | Clear, concise, and universally understood definitions of organizations are crucial for your organization and stakeholders. This clarity is key to facilitating effective analysis and generating insightful outcomes within SAP LeanIX.


### Applications
The following table lists best practice metrics and explanations for application fact sheets.
Best Practice | Explanation
---|---
Applications* are added to the workspace, using at least 60% of the quota. | An important prerequisite for effective enterprise architecture governance is creating transparency in your entire application portfolio. We encourage importing all known applications into the workspace, aiming for at least 60% of your quota to start. To reflect the focus of your current architecture work, use the "In scope" field for a focused subset of your landscape. See the following metric for more details.
At least 20 applications* are in scope. | When you're getting onboarded to SAP LeanIX, start with at least 20 critical applications. After assessing the initial set of applications, extend the scope.
At least 20 applications* have a description. | Application descriptions help stakeholders understand their purpose. Names alone may not be universally understood. To streamline the process of creating descriptions, you can use AI capabilities, available in the upper-right corner of the inventory. For more information, see [AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "AI capabilities in SAP LeanIX automate documentation tasks, offer contextual insights, and support natural language queries to streamline enterprise architecture management. Use it to boost efficiency, reduce manual work, and maintain compliance with data privacy and ethical standards.").
At least 20 applications* have a subscriber of type Responsible. | Accurate, comprehensive, and up-to-date information in your inventory is crucial. Assigning fact sheet responsibility and ownership through subscriptions enables you to ensure information reliability.
At least 20 applications* are linked to business capabilities. At least 20 applications* are linked to organizations. | Establishing accurate relations is crucial for deriving meaningful insights from reports. The metric does not cover relations between application fact sheets of the deployment subtype and organization fact sheets. To learn more, see [Application Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275892ca7a441014ab86c9b2e6382a33__application_fact_sheet_subtypes).
At least 20 applications* have a lifecycle other than N/A. | This is important for obsolescence risk management. Also, it enables you to focus on applications that are not already terminated.
At least 20 applications with business criticality, functional fit, and technical fit assessed. | These are key input factors for application portfolio assessment and TIME classification assessment.
At least 20 applications* with an approved quality seal. | This ensures data quality validation through fact sheet owners.


* Count all application fact sheets where the subtype is business application or empty.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
